Data sample of 1,182 people from a survey conducted by Thomson and Crooke (1991) and analyzed by Herriges and Kling (1999). Cameron and Trivedi (2005).
fishingA data frame with 1182 observations and 16 variables:
fishing mode choice, = 1 beach, = 2 pier, = 3 private boat, = 4 charter boat
price for chosen alternative, usd
catch rate for chosen alternative, sum of per-hour catch rates of targeted species.
= 1 if beach mode chosen, = 0 otherwise
= 1 if pier mode chosen, = 0 otherwise
= 1 if private boat mode chosen, = 0 otherwise
= 1 if charter boat mode chosen, = 0 otherwise
price for beach mode, usd
price for pier mode, usd
price for private boat mode, usd
price for charter boat mode, usd
catch rate for beach mode
catch rate for pier mode
catch rate for private boat mode
catch rate for charter boat mode
monthly income, usd
14.2 Binary Outcome Example: Fishing Mode Choice, pp. 464-6, 486
15.2 Choice of Fishing Mode, pp. 491-5
Cameron, A. and Trivedi, P. (2005), "Microeconometrics: Methods and Applications," Cambridge University Press, New York.
Herriges, J. and Kling, C. (1999), "Nonlinear Income Effects in Random Utility Models," Review of Economics and Statistics, 81, 62-72.
Thomson, C., and Crooke, S. (1991), "Results of the Southern California Sportfish Economic Survey," NOAA Technical Memorandum, National Marine Fisheries Service, Southwest Fisheries Science Center.
# NOT RUN {
summary(fishing)
# }
Run the code above in your browser using DataLab